==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_ul = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.uz = function () {
        _super.prototype.uz.call(this);
        this.u6 = this.u7;
        this.uk.c = this.u6;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };

==> igniteui-react-charts-18.2.0.tgz: package/esm5/lib/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_up = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.vc = function () {
        return true;
    };
    ItemwiseStrategyBasedIndicator.prototype.u3 = function () {
        _super.prototype.u3.call(this);
        this.va = this.vb;
        this.uo.c = this.va;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };
